@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.documentconverter;
 
 import java.io.File;
@@ -76,6 +74,10 @@ public class DataSourceFile implements Serializable {
        if (null != objInputStm) {
            Object readObj = null;
 
+           if (objInputStm instanceof DataSourceFileInputStream) {
+               ((DataSourceFileInputStream) objInputStm).setContext(this.getClass().getName());
+           }
+
            objInputStm.defaultReadObject();
 
            if ((null != (readObj = objInputStm.readObject())) && (readObj instanceof Integer)) {
